Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(53)

Unified Diff: content/browser/accessibility/browser_accessibility_manager_android.cc

Issue 1884723003: Accessible location change events need to update internal data structure (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/accessibility/browser_accessibility_manager_android.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/accessibility/browser_accessibility_manager_android.cc
diff --git a/content/browser/accessibility/browser_accessibility_manager_android.cc b/content/browser/accessibility/browser_accessibility_manager_android.cc
index 20599dc90586bd1141725740018226574f70a1d7..b0d8c9ccce77995f2c7980e058747639dd5bf848 100644
--- a/content/browser/accessibility/browser_accessibility_manager_android.cc
+++ b/content/browser/accessibility/browser_accessibility_manager_android.cc
@@ -208,7 +208,8 @@ void BrowserAccessibilityManagerAndroid::NotifyAccessibilityEvent(
if (event_type == ui::AX_EVENT_TREE_CHANGED)
return;
// Layout changes are handled in OnLocationChanges.
if (event_type == ui::AX_EVENT_LAYOUT_COMPLETE)
return;
@@ -281,7 +282,7 @@ void BrowserAccessibilityManagerAndroid::NotifyAccessibilityEvent(
}
}
-void BrowserAccessibilityManagerAndroid::OnLocationChanges(
+void BrowserAccessibilityManagerAndroid::SendLocationChangeEvents(
const std::vector<AccessibilityHostMsg_LocationChangeParams>& params) {
// Android is not very efficient at handling notifications, and location
// changes in particular are frequent and not time-critical. If a lot of
@@ -297,7 +298,7 @@ void BrowserAccessibilityManagerAndroid::OnLocationChanges(
return;
}
- BrowserAccessibilityManager::OnLocationChanges(params);
+ BrowserAccessibilityManager::SendLocationChangeEvents(params);
}
base::android::ScopedJavaLocalRef<jstring>
« no previous file with comments | « content/browser/accessibility/browser_accessibility_manager_android.h ('k') | no next file » | no next file with comments »
@@ -208,7 +208,8 @@ void BrowserAccessibilityManagerAndroid::NotifyAccessibilityEvent(
if (event_type == ui::AX_EVENT_TREE_CHANGED)
return;
- // Layout changes are handled in OnLocationChanges.
+ // Layout changes are handled in OnLocationChanges and
+ // SendLocationChangeEvents.
if (event_type == ui::AX_EVENT_LAYOUT_COMPLETE)
return;

Powered by Google App Engine
This is Rietveld 408576698